Remove initial line feed ▲ Prism plugins

# How to use (DEPRECATED)

This plugin will be removed in the future. Please use the general purpose Normalize Whitespace plugin instead.

Obviously, this is supposed to work only for code blocks (`<pre><code>`) and not for inline code.

With this plugin included, any initial line feed will be removed by default.

To bypass this behaviour, you may add the class keep-initial-line-feed to your desired `<pre>`.

# Examples

## Without adding the class

    <div></div>

## With the class added

    <div></div>